## Cookies Policy

In Übereinstimmung mit dem Gesetzesdekret Nr. 196/2003, das das Gesetz Nr. 675/1996 zum Schutz personenbezogener Daten ersetzt, informieren wir Sie, dass Sie mit der weiteren Nutzung dieser Website der Verarbeitung Ihrer persönlichen Daten (sensible Daten werden in keiner Weise behandelt), die GeoSolutions SAS durch elektronische und/oder automatische Tools erworben hat, zustimmen. In jedem Fall ist es möglich, die Rechte zu nutzen, die dem Benutzer in Übereinstimmung mit Gesetzesdekret Nr. 196/2003 (Zugang zu Daten, Aktualisierung, Integration, Löschung) gewährt werden. Durch Klicken auf den Button "Akzeptieren" erklären Sie, dass Sie diesen Text gelesen haben und der Verarbeitung personenbezogener Daten zustimmen. Sie können die Redakteure von GeoSolutions SAS jederzeit bitten, sich von dem Dienst abzumelden, indem Sie den Anweisungen am Ende jeder Nachricht folgen.

#### Was sind Cookies?

Ein Cookie ist eine Textdatei, die eine Website im Browser des Benutzers speichert. Cookies erlauben normalerweise, die vom Benutzer geäußerten Präferenzen zu speichern, um später nicht wieder eingefügt zu werden. Der Browser speichert die Informationen und sendet sie an den Standortserver zurück, wenn der Benutzer diese Website erneut besucht.

Unsere Cookies helfen uns:

- Die Website wie erwartet funktionieren zu lassen
- Die Einstellungen während und zwischen den Besuchen der Seite zu merken
- Die Geschwindigkeit der Website-Sicherheit zu verbessern
- Es erlaubt Seiten mit sozialen Netzwerken wie Facebook zu teilen

Cookies werden nicht verwendet um:

- Alle persönlich identifizierbaren Informationen (ohne Ihre Zustimmung) zu sammeln
- Alle sensible Daten (ohne explizite Zustimmung) zu sammeln
- Daten an Werbenetzwerke zu übergeben
- Personenbezogener Daten an Dritte weiterzugeben
- Kostenpflichtige Verkaufsaufträge zu tätigen

Hier unten können Sie mehr über alle Cookies die wir verwende, erfahren.

Wenn die Einstellungen der Software, die Sie zum Durchsuchen der Website (des Browsers) verwenden, auf das Akzeptieren von Cookies eingestellt sind, akzeptieren wir diese und die fortgesetzte Nutzung unserer Website als Zustimmung zur Verwendung von Cookies. Wenn Sie Cookies von unserer Website entfernen oder nicht verwenden möchten, können Sie dies tun, indem Sie den unten stehenden Anweisungen folgen. Dies könnte jedoch dazu führen, dass unsere Website nicht wie erwartet funktioniert.

#### Unsere Cookies

Wir verwenden Cookies, um bestimmte Funktionen der Website zu gewährleisten, einschließlich:

- Anmeldevorgänge und anschließende Authentifizierung
- Authentifizierung für WMS-, WFS-, WPS-Dienste über HTTP-Anfragen

Es gibt keine Möglichkeit zu verhindern, dass diese Cookies gesetzt werden, als unsere Seite nicht zu benutzen.

#### Cookies von Dritten

Unsere Website enthält wie viele andere Funktionen und Dienste, die von Dritten angeboten werden. Ein gängiges Beispiel ist die Einbettung eines YouTube-Videos. Unsere Website enthält die folgenden Cookies:

- Google
- Cloudflare

#### Social Website Cookies

Sie können einfach Ihre Meinung äußern oder Inhalte auf Facebook und Twitter teilen (wir haben die Freigabetasten auf unserer Seite eingefügt). Cookies wurden aktiviert für:

- Twitter
- Facebook
- Linkedin
- Google +

Die Auswirkungen auf die Privatsphäre variieren von sozialen Netzwerken zu sozialen Netzwerken und hängen von den Datenschutzeinstellungen ab, die Sie in diesen Netzwerken gewählt haben.

#### Deaktivieren von Cookies

Normalerweise können Sie Cookies deaktivieren, indem Sie Ihre Browsereinstellungen ändern, um deren Verwendung zu verhindern(siehe hier). Dies wird jedoch wahrscheinlich die Funktionalität unserer sowie vieler Websites auf der ganzen Welt einschränken (Cookies sind ein Standardbestandteil der meisten modernen Websites).

Es kann sein, dass sich Ihre Cookie-bezogenen Bedenken auf sogenannte "Spyware" beziehen. Anstatt die Cookies in Ihrem Browser zu deaktivieren, können Sie erkennen, dass die Anti-Spyware-Software das gleiche Ziel erreicht, indem Cookies, die als invasiv angesehen werden, automatisch entfernt werden. Bitte lesen wieSie Cookies mit Anti-Spyware-Software verwalten.